#include <iostream>
#include <string>
#include <queue>
#include <algorithm>
#include <set>
#include <cassert>

using namespace std;
using ll = long long;

const int N = 10000;
const int K = 19;
const int MOD = 1e9+21;
const int B = 734;

struct mod {
    int x;

    mod(ll y = 0) : x(y % MOD) {
        if (x < 0) x += MOD;
    }

    mod operator + (mod m) { 
        int t = x + m.x;
        if (t >= MOD) t -= MOD;
        return mod { t };
    }

    mod operator - (mod m) {
        int t = x - m.x;
        if (t < 0) t += MOD;
        return mod { t };
    }

    mod operator * (mod m) {
        return mod { (ll) m.x * x % MOD };
    }

    bool operator == (mod m) const {
        return x == m.x;
    }
};

string s;
int len[N], up[K][N], tmin[2*N];
mod hup[K][N];

bool cmp(int i, int j) {
    //cout << "cmp " << i << " and " << j << endl;
    while (len[i] || len[j]) {
        if (!len[j]) return false;
        if (!len[i]) return true;
        if (s[i] != s[j]) return s[i] < s[j];
        i = up[0][i], j = up[0][j];
    }
    return false;
}

int query(int l, int r, int n) {

    int ans = l;
    l += n, r += n;
    for (; l <= r; l >>= 1, r >>= 1) {
        if ((l & 1) == 1) ans = min(ans, tmin[l++], cmp);
        if ((r & 1) == 0) ans = min(ans, tmin[r--], cmp);
    }
    return ans;
}

void connect(int i, int j) {
    up[0][i] = j;
    len[i] = len[j] + 1;
}

int main() {
    int k, n; cin >> k >> n;
    vector<int> len(n);
    vector t(k, vector<bool>(k));
    for (int i = 0; i < k; ++i) {
        string s; cin >> s;
        for (int j = 0; j < k; ++j) t[i][j] = s[j] == '1';
    }

    for (int i = 0; i < K; ++i) up[i][n] = n;

    cin >> s;
    vector<int> dp(n, 0);
    vector<int> gomin(n), gomax(n);

    const int sz = n+1;
    
    for (int i = 0; i < sz; ++i) tmin[i+sz] = i;
    for (int i = sz; --i; ) tmin[i] = min(tmin[2*i], tmin[2*i+1]);

    for (int i = 0; i < n; ++i) {
        gomin[i] = gomax[i] = i + 1;
    }

    for (int i = 1; i < n; ++i) {
        dp[i] = i;
        int j = i - 1;
        while(t[s[j]-'a'][s[i]-'a'] == 0 && j != dp[j]) {
            j = dp[j];
        }
        if (t[s[j]-'a'][s[i]-'a']) dp[i] = j;
        if (dp[i] < i) {
            int j = dp[i];
            gomax[j] = i + 1;
        }
    }

    for (int i = n; i--; ) {
        if (gomax[i] < n && gomax[i] > i+1) {
            gomax[i] = gomax[gomax[i]-1];
        }
    }

    for (int i = n; i--; ) {
        int u = query(gomin[i], gomax[i], sz);
        connect(i, u);
        tmin[i+n+1] = i;
        for (int j = i+sz; j != 1; j >>= 1) {
            tmin[j >> 1] = cmp(tmin[j], tmin[j^1]) ? tmin[j] : tmin[j^1];
        }
        // cout << i << " -> " << u << endl;
    }

    string ans;
    for (int i = 0; i < n; i = up[0][i]) ans.push_back(s[i]);
    cout << ans << endl;
}