#define _GLIBCXX_DEBUG

#include <bits/stdc++.h>

#include <utility>

#define range(collection) collection.begin(), collection.end()
using namespace std;

void solve();

signed main() {
    cin.tie(nullptr);
    ios_base::sync_with_stdio(false);
    solve();
}

using segment = pair<int, int>;
#define l first
#define r second

struct state {
    segment first;
    mutable vector<int> second;

    state(segment first, vector<int> second) : first(std::move(first)), second(std::move(second)) {}

    bool operator<(const state &other) const { return first < other.first; }
};

set<state> compress(set<state> vv) {
    if (vv.empty()) return vv;
    vector<state> v(range(vv));
    sort(v.begin(), v.end(),
         [](auto s1, auto s2) { return pair{-s1.first.l, s1.first.r} < pair{-s2.first.l, s2.first.r}; });
    vector<state> res{v[0]};
    for (int i = 1; i < v.size(); ++i) {
        if (v[i].first.r >= res.back().first.r) continue;
        res.push_back(v[i]);
    }
    reverse(range(res));
    return set<state>(range(res));
}

set<state> operator+=(set<state> &a, const set<state> &b) {
    for (const auto &x : b) a.emplace(x);
    return a = compress(a);
}

vector<int> operator+(vector<int> a, const vector<int> &b) {
    for (auto x : b) a.push_back(x);
    return a;
}

set<state> merge(set<state> a, set<state> b) {
    if (a.size() > b.size()) return merge(b, a);
    set<state> res;
    for (auto[s1, ord1] : a) {
        if (auto it = b.lower_bound(state({s1.r, -1}, {})); it != b.end()) {
            auto[s2, ord2] = *it;
            res.emplace(segment{s1.l, s2.r}, ord1 + ord2);
        }
        if (auto it = b.upper_bound(state({s1.l, -1}, {})); it != b.end()) {
            auto[s2, ord2] = *it;
            res.emplace(segment{s1.l, s2.r}, ord2 + ord1);
        }
    }

    return compress(res);
}

set<state> zip(set<state> prev, const vector<int> &ord) {
    for (auto &[s, o] : prev) o = ord;
    return prev;
}

void dfs(vector<set<state>> &segments, const vector<vector<int>> &tree, int cur) {
    if (tree[cur].empty()) return;
    for (int next : tree[cur]) {
        dfs(segments, tree, next);
        if (segments[next].empty()) return;
    }
    int sz = tree[cur].size();
    vector<set<state>> dp(1 << sz);
    for (int mask = 1; mask < dp.size(); ++mask) {
        for (int bit = 0; bit < sz; ++bit) {
            if (!(mask & (1 << bit))) continue;
            if (mask == (1 << bit)) {
                dp[mask] = zip(segments[tree[cur][bit]], {tree[cur][bit]});
            } else {
                int other = mask & (~(1 << bit));
                dp[mask] += merge(dp[other], dp[1 << bit]);
            }
        }
    }
    segments[cur] = dp.back();
}

int restore(vector<vector<int>> &certificate, vector<set<state>> &segments, int cur, int l) {
    auto s = segments[cur].lower_bound(state{{l, -1},
                                             {}});
    if (s->second[0] != cur) {
        certificate[cur] = s->second;
        for (int &x: certificate[cur]) ++x;
        for (int next : s->second) {
            l = restore(certificate, segments, next, l);
        }
    } else {
        certificate[cur] = {s->first.l};
        l = s->first.r;
    }
    return l;
}

void solve() {
    int n;
    cin >> n;
    vector<vector<int>> tree(n);
    vector<set<state>> segments(n);
    for (int i = 0; i < n; ++i) {
        int l;
        cin >> l;
        int k;
        cin >> k;
        bool leaf = (l == 2);
        if (leaf) {
            for (int j = 0; j < k; ++j) {
                int x;
                cin >> x;
                segments[i].emplace(segment{x, x + 1}, vector{i});
            }
        } else {
            for (int j = 0; j < k; ++j) {
                int x;
                cin >> x;
                tree[i].emplace_back(x - 1);
            }
        }
    }
    dfs(segments, tree, 0);
    if (segments[0].empty()) {
        cout << "NO\n";
    } else {
        cout << "YES\n";
        vector<vector<int>> certificate(n);
        restore(certificate, segments, 0, segments[0].begin()->first.l);
        for (auto &row : certificate) {
            for (int x : row) cout << x << ' ';
            cout << '\n';
        }
    }
}
