#include <iostream>
#include <vector>
#include <queue>
#include <ios>
#include <set>
#include <cassert>
using namespace std;

const int MAX_K = 26;
bool can_delete[MAX_K][MAX_K];

const int MAX_LOG = 20;
const int p = 239;

unsigned long long xp[MAX_LOG];

void init_xp() {
	xp[0] = p;
	for (int i = 1; i < MAX_LOG; i++) {
		xp[i] = xp[i - 1] * xp[i - 1];
	}
}

struct string_hasher {
	char symbol;
	string_hasher* binary_jumps[MAX_LOG];
	unsigned long long hashes[MAX_LOG];
	int length;

	string_hasher(char symbol, string_hasher* next) : symbol(symbol) {
		length = 1;
		if (next)
			length += next->length;

		binary_jumps[0] = next;
		for (int i = 1; i < MAX_LOG; i++) {
			binary_jumps[i] = binary_jumps[i - 1];
			if (binary_jumps[i]) {
				binary_jumps[i] = binary_jumps[i]->binary_jumps[i - 1];
			}
		}

		hashes[0] = symbol + 1;
		for (int i = 1; i < MAX_LOG; i++) {
			hashes[i] = hashes[i - 1];
			hashes[i] *= xp[i - 1];
			auto next = binary_jumps[i - 1];
			if (next)
				hashes[i] += next->hashes[i - 1];
		}
	}

	void print_to_cout() {
		cout << (char)(symbol + 'a');
		if (binary_jumps[0])
			binary_jumps[0]->print_to_cout();
	}
};

bool is_less(string_hasher* a, string_hasher* b) {
	if (a == nullptr && b == nullptr)
		return false;
	if (a == nullptr)
		return true;
	if (b == nullptr)
		return false;

	for (int i = MAX_LOG - 1; i >= 0; i--) {
		int len = (1 << i);
		if (len <= a->length && len <= b->length) {
			if (a->hashes[i] == b->hashes[i]) {
				return is_less(a->binary_jumps[i], b->binary_jumps[i]);
			}
		}
	}

	return a->symbol < b->symbol;
}

string_hasher* inf_string = new string_hasher('{', nullptr);


const int MAX_N = 500002;
string_hasher* t[4 * MAX_N];

string_hasher* get_min(int v, int tl, int tr, int l, int r) {
	if (l >= r)
		return inf_string;
	if (l == tl && r == tr)
		return t[v];
	int tm = (tl + tr) / 2;
	string_hasher* min1 = get_min(2 * v + 1, tl, tm, l, min(r, tm));
	string_hasher* min2 = get_min(2 * v + 2, tm, tr, max(tm, l), r);
	if (is_less(min1, min2))
		return min1;
	else
		return min2;
}

void update(int v, int tl, int tr, int pos, string_hasher* new_val) {
	if (tr - tl == 1)
		t[v] = new_val;
	else {
		int tm = (tl + tr) / 2;
		if (pos < tm)
			update(2 * v + 1, tl, tm, pos, new_val);
		else
			update(2 * v + 2, tm, tr, pos, new_val);
		string_hasher* min1 = t[2 * v + 1];
		string_hasher* min2 = t[2 * v + 2];
		if (is_less(min1, min2))
			t[v] = min1;
		else
			t[v] = min2;
	}
}


int main() {
	init_xp();

	ios_base::sync_with_stdio(0); cin.tie(0); cout.tie(0);
	int k, n;
	cin >> k >> n;
	for (int i = 0; i < k; i++) {
		for (int j = 0; j < k; j++) {
			char c;
			cin >> c;
			can_delete[i][j] = (c == '1');
		}
	}

	string s;
	cin >> s;
	for (int i = 0; i < n; i++) {
		s[i] -= 'a';
	}

	vector<int> max_delete_after(n);
	for (int i = n - 1; i >= 0; i--) {
		while (max_delete_after[i] != n - 1 - i) {
			int next = i + max_delete_after[i] + 1;
			if (!can_delete[s[i]][s[next]])
				break;
			max_delete_after[i] += 1 + max_delete_after[next];
		}
	}

	vector<string_hasher*> min_string_starting_with(n + 1);
	for (int i = n - 1; i >= 0; i--) {
		int max_delete = max_delete_after[i];
		auto min_string = get_min(0, 0, n + 1, i + 1, i + 1 + max_delete_after[i] + 1);
		min_string_starting_with[i] = new string_hasher(s[i], min_string);
		update(0, 0, n + 1, i, min_string_starting_with[i]);
	}

	auto ans = min_string_starting_with[0];
	ans->print_to_cout();
}