//
// Created by roi on 09.04.2021.
//

#include <bits/stdc++.h>

using namespace std;

using ll = long long;

template<typename T>
using vec = vector<T>;

#define int ll

const int N = 100;

namespace flows {

struct Edge {
  int u;
  int v;
  int f;
  int c;
};

vec<Edge> edges;

vec<int> g[N];

void init() {
  edges.clear();
  for (int i = 0; i < N; i++) {
    g[i].clear();
  }
}

void add_edge(int u, int v) {
  g[u].push_back(edges.size());
  edges.push_back({u, v, 0, 1});
  g[v].push_back(edges.size());
  edges.push_back({v, u, 0, 0});
}

int lvl[N];

bool bfs(int s, int t) {
  queue<int> q;
  q.push(s);
  memset(lvl, -1, sizeof lvl);
  lvl[s] = 0;
  while (!q.empty()) {
    int u = q.front();
    q.pop();
    for (auto id : g[u]) {
      auto &e = edges[id];
      if (lvl[e.v] == -1 && e.f < e.c) {
        lvl[e.v] = lvl[e.u] + 1;
        q.push(e.v);
      }
    }
  }
  return lvl[t] != -1;
}

int ptr[N];

int dfs(int u, int flow, int t) {
  if (flow == 0 || u == t) {
    return flow;
  }
  for (; ptr[u] < g[u].size(); ptr[u]++) {
    int id = g[u][ptr[u]];
    auto &e = edges[id];
    if (lvl[e.u] + 1 == lvl[e.v]) {
      int pushed = dfs(e.v, min(flow, e.c - e.f), t);
      if (pushed > 0) {
        edges[id].f += pushed;
        edges[id ^ 1].f -= pushed;
        return pushed;
      }
    }
  }
  return 0;
}

int max_flow(int s, int t) {
  int ans = 0;
  while (bfs(s, t)) {
    memset(ptr, 0, sizeof ptr);
    int pushed = 0;
    do {
      pushed = dfs(s, 1, t);
      ans += pushed;
    } while (pushed != 0);
  }
  return ans;
}

}

void run() {
  int n, m;
  cin >> n >> m;
  vec<pair<int, int>> edges(m);
  for (auto &[u, v] : edges) {
    cin >> u >> v;
  }
  int s = N - 1;
  int t = N - 2;
  for (int mask = 0; mask < (1 << m); mask++) {
    if (__builtin_popcount(mask) != m / 2)
      continue;
    flows::init();
    for (int i = 0; i < m; i++) {
      flows::add_edge(s, i);
      flows::add_edge(i + m, t);
      for (int j = 0; j < m; j++) {
        if (mask & (1 << i) && !(mask & (1 << j))) {
          if (edges[i].second == edges[j].first) {
            flows::add_edge(i, j + m);
          }
        }
      }
    }
    int flow = flows::max_flow(s, t);
    if (flow == m / 2) {
      cout << "Yes\n";
      for (auto [u, v, f, c] : flows::edges) {
        if (f == 1 && u != s && v != t) {
          cout << edges[u].first << ' ' << edges[u].second << ' ';
          cout << edges[v - m].first << ' ' << edges[v - m].second << '\n';
        }
      }
      return;
    }
  }
  cout << "No\n";
}

signed main() {
#ifdef LOCAL
  freopen("input.txt", "r", stdin);
#else
  ios_base::sync_with_stdio(false);
  cin.tie(nullptr);
#endif
  run();
  return 0;
}