#include <bits/stdc++.h>

std::mt19937 rnd;

class bigInt {
private:
    std::vector<int> num;
    bool negative;
public:
    explicit bigInt(std::vector<int> num) : num(std::move(num)), negative(false) {}

    bigInt(std::vector<int> num, const bool &negative) : num(std::move(num)), negative(negative) {}

    bigInt(const std::string &s) {
        int ind = 0;
        if (s[0] == '-') negative = true, ind++;
        else negative = false;
        for (int i = s.size() - 1; i >= ind; i--) num.push_back(s[i] - '0');
    }

    std::vector<int> getNum() const {
        return num;
    }

    bigInt operator+(const bigInt &sec) const;

    bigInt operator-(const bigInt &sec) const;

    bigInt operator-() const {
        bigInt res = *this;
        res.negative ^= 1;
        return res;
    }

    std::string to_string() const {
        std::string res;
        for (auto &i : num) res += i + '0';

        while (res.size() > 1 && res.back() == '0') res.pop_back();
        std::reverse(res.begin(), res.end());
        if (res != "0" && negative) res = "-" + res;
        return res;
    }
};

bigInt bigInt::operator-(const bigInt &sec) const {
    return bigInt(sec);
}

bigInt bigInt::operator+(const bigInt &sec) const {
    bool neg = (negative && sec.negative);
    if (negative && !sec.negative) {
        return sec - *this;
    }
    if (!negative && sec.negative) {
        return *this - sec;
    }

    std::vector<int> ans = sec.getNum();
    ans.resize(std::max(sec.num.size() + 1, num.size() + 1));
    int shift = 0;
    for (int i = 0; i < ans.size(); i++) {
        int first = (i < num.size() ? num[i] : 0);
        int second = (i < sec.num.size() ? sec.num[i] : 0);
        int val = (first + second + shift);
        ans[i] = val % 10;
        shift = val / 10;
    }

    return bigInt(ans, neg);
}

struct node {
    int sz, y, val;
    node *l, *r;
    bool rev;

    node() : sz(0), y(rnd()), val(0), l(nullptr), r(nullptr), rev(0) {}
    node(int val) : sz(1), y(rnd()), val(val), l(nullptr), r(nullptr), rev(0) {}
    node(int val, int sz) : sz(sz), y(rnd()), val(val), l(nullptr), r(nullptr), rev(0) {}
};

typedef node * pnode;

int getSz(pnode &root) {
    return (root == nullptr ? 0 : root->sz);
}

void updSz(pnode &root) {
    root->sz = getSz(root->l) + getSz(root->r) + 1;
}

std::pair<pnode, pnode> split(pnode &root, int key) {
    if(root == nullptr) return std::make_pair(nullptr, nullptr);

    int leftSz = getSz(root->l);
    if(leftSz >= key) {
        auto [t1, t2] = split(root->l, key);
        root->r = t2;
        updSz(root);
        return std::make_pair(t1, root);
    }
    else {
        auto [t1, t2] = split(root->r, key - 1 - leftSz);
        root->l = t2;
        updSz(root);
        return std::make_pair(root, t2);
    }
}

void merge(pnode &res, pnode left, pnode right) {
    if(left == nullptr) {
        res = right;
        updSz(res);
        return;
    }
    if(right == nullptr) {
        res = left;
        updSz(res);
        return;
    }
    if(left->y > right->y) {
        res = left;
        merge(left->r, left->r, right);
        updSz(res);
    }
    else {
        res = right;
        merge(res->l, left, right->l);
        updSz(res);
    }
}

int getElement(pnode &root, int ind) {
    if(root->rev) {
        if(root->l) root->l->rev ^= 1;
        if(root->r) root->r->rev ^= 1;
        root->rev = 0;
        std::swap(root->l, root->r);
    }
    int leftSz = getSz(root->l);
    if(leftSz >= ind) return getElement(root->l, ind);
    else if(leftSz + 1 == ind) return root->val;
    else return getElement(root->r, ind - leftSz - 1);
}

void push_back(pnode &root, int val) {
    pnode el = new node(val, getSz(root));
    merge(root, root, el);
}

void reverse(pnode &root) {
    root->rev ^= 1;
}

int main() {
    std::vector<int> a;
    int i;
    while(std::cin >> i) {
        a.push_back(i);
    }

    pnode root = new node(a[0]);

    for(int i = 1; i < a.size(); i++) push_back(root, a[i]);

    reverse(root);

    for(int i = 0; i < a.size(); i++) std::cout << getElement(root, i + 1) << ' ';
}