#include <iostream>
#include <iomanip>
#include <vector>
#include <cstdio>
#include <map>

using namespace std;

struct big_number{
  bool sign;
  vector<int> num;
  big_number() {
    num.resize(1, 0);
    sign = true;
  }
  big_number(int x) {
    sign = true;
    if (x < 0) {
      x *= -1;
      sign = false;
    }
    if (x == 0) {
      num.resize(1, 0);
      return;
    }
    while (x) {
      num.emplace_back(x % 10);
      x /= 10;
    }
  }
  big_number(string s) {
    sign = true;
    if (s[0] == '-') {
      s = s.substr(1, s.size() - 1);
      sign = false;
    }
    num.resize(s.size());
    for (int i = 0; i < s.size(); ++i)
      num[i] = s[s.size() - i - 1] - '0';
  }
};

bool is_zero(const big_number &x) {
  return x.num.size() == 1 && x.num[0] == 0;
}

bool operator <(const big_number &a, const big_number &b) {
  if (a.sign != b.sign)
    return !a.sign;
  if (a.sign) {
    if (a.num.size() < b.num.size())
      return true;
    if (a.num.size() > b.num.size())
      return false;
    for (int i = a.num.size() - 1; i >= 0; --i) {
      if (a.num[i] < b.num[i])
        return true;
      if (a.num[i] > b.num[i])
        return false;
    }
    return false;
  }
  if (a.num.size() < b.num.size())
    return false;
  if (a.num.size() > b.num.size())
    return true;
  for (int i = a.num.size() - 1; i >= 0; --i) {
    if (a.num[i] < b.num[i])
      return false;
    if (a.num[i] > b.num[i])
      return true;
  }
  return false;
}

big_number operator -(const big_number &a) {
  big_number ans = a;
  ans.sign = !ans.sign;
  if (is_zero(a))
    ans.sign = true;
  return ans;
}

bool operator ==(const big_number &a, const big_number &b) {
  if (a.sign != b.sign)
    return false;
  if (a.num.size() != b.num.size())
    return false;
  for (int i = 0; i < a.num.size(); ++i) {
    if (a.num[i] != b.num[i])
      return false;
  }
  return true;
}

bool operator >(const big_number &a, const big_number &b) {
  return b < a;
}

bool operator <=(const big_number &a, const big_number &b) {
  return !(b < a);
}

bool operator >=(const big_number &a, const big_number &b) {
  return !(a < b);
}

//positive + positive
big_number add(const big_number &a, const big_number &b) {
  big_number c;
  c.num.resize(max(a.num.size(), b.num.size()) + 1);
  for (int i = 0; i < max(a.num.size(), b.num.size()); ++i) {
    c.num[i] += (i < a.num.size() ? a.num[i] : 0) + (i < b.num.size() ? b.num[i] : 0);
    if (c.num[i] >= 10) {
      c.num[i + 1] += 1;
      c.num[i] -= 10;
    }
  }
  while (c.num.size() > 1 && c.num.back() == 0)
    c.num.pop_back();
  return c;
}

//positive - positive, a >= b
big_number sub(const big_number &a, const big_number &b) {
  big_number c;
  c.num.resize(a.num.size());
  for (int i = 0; i < a.num.size(); ++i) {
    c.num[i] += a.num[i] - b.num[i];
    if (c.num[i] < 0) {
      c.num[i] += 10;
      --c.num[i + 1];
    }
  }
  while (c.num.size() > 1 && c.num.back() == 0)
    c.num.pop_back();
  return c;
}

big_number operator +(const big_number &a, const big_number &b) {
  if (a.sign && b.sign) {
    return add(a, b);
  } else if (a.sign && !b.sign) {
    big_number c = -b;
    if (a >= c)
      return sub(a, c);
    return -sub(c, a);
  } else if (!a.sign && b.sign) {
    big_number c = -a;
    if (b >= c)
      return sub(b, c);
    return -sub(c, b);
  } else {
    return -add(-a, -b);
  }
}

big_number operator -(const big_number &a, const big_number &b) {
  if (a.sign && b.sign) {
    if (a >= b)
      return sub(a, b);
    return -sub(b, a);
  } else if (a.sign && !b.sign) {
    return add(a, -b);
  } else if (!a.sign && b.sign) {
    return -add(-a, b);
  } else {
    big_number c = -a;
    big_number d = -b;
    if (d >= c)
      return sub(d, c);
    return -sub(c, d);
  }
}

int main() {
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#else
  ios::sync_with_stdio(false);
  cin.tie(0);
  cout.tie(0);
#endif

  #include <map>
#include <cstdio>
#include <vector>
#include <iomanip>
#include <iostream>
#include <algorithm>

using namespace std;

struct big_number{
  bool sign;
  vector<int> num;
  big_number() {
    num.resize(1, 0);
    sign = true;
  }
  big_number(int x) {
    sign = true;
    if (x < 0) {
      x *= -1;
      sign = false;
    }
    if (x == 0) {
      num.resize(1, 0);
      return;
    }
    while (x) {
      num.emplace_back(x % 10);
      x /= 10;
    }
  }
  big_number(string s) {
    sign = true;
    if (s[0] == '-') {
      s = s.substr(1, s.size() - 1);
      sign = false;
    }
    num.resize(s.size());
    for (int i = 0; i < s.size(); ++i)
      num[i] = s[s.size() - i - 1] - '0';
  }
};

bool is_zero(const big_number &x) {
  return x.num.size() == 1 && x.num[0] == 0;
}

bool operator <(const big_number &a, const big_number &b) {
  if (a.sign != b.sign)
    return !a.sign;
  if (a.sign) {
    if (a.num.size() < b.num.size())
      return true;
    if (a.num.size() > b.num.size())
      return false;
    for (int i = a.num.size() - 1; i >= 0; --i) {
      if (a.num[i] < b.num[i])
        return true;
      if (a.num[i] > b.num[i])
        return false;
    }
    return false;
  }
  if (a.num.size() < b.num.size())
    return false;
  if (a.num.size() > b.num.size())
    return true;
  for (int i = a.num.size() - 1; i >= 0; --i) {
    if (a.num[i] < b.num[i])
      return false;
    if (a.num[i] > b.num[i])
      return true;
  }
  return false;
}

big_number operator -(const big_number &a) {
  big_number ans = a;
  ans.sign = !ans.sign;
  if (is_zero(a))
    ans.sign = true;
  return ans;
}

bool operator ==(const big_number &a, const big_number &b) {
  if (a.sign != b.sign)
    return false;
  if (a.num.size() != b.num.size())
    return false;
  for (int i = 0; i < a.num.size(); ++i) {
    if (a.num[i] != b.num[i])
      return false;
  }
  return true;
}

bool operator >(const big_number &a, const big_number &b) {
  return b < a;
}

bool operator <=(const big_number &a, const big_number &b) {
  return !(b < a);
}

bool operator >=(const big_number &a, const big_number &b) {
  return !(a < b);
}

//positive + positive
big_number add(const big_number &a, const big_number &b) {
  big_number c;
  c.num.resize(max(a.num.size(), b.num.size()) + 1);
  for (int i = 0; i < max(a.num.size(), b.num.size()); ++i) {
    c.num[i] += (i < a.num.size() ? a.num[i] : 0) + (i < b.num.size() ? b.num[i] : 0);
    if (c.num[i] >= 10) {
      c.num[i + 1] += 1;
      c.num[i] -= 10;
    }
  }
  while (c.num.size() > 1 && c.num.back() == 0)
    c.num.pop_back();
  return c;
}

//positive - positive, a >= b
big_number sub(const big_number &a, const big_number &b) {
  big_number c;
  c.num.resize(a.num.size());
  for (int i = 0; i < a.num.size(); ++i) {
    c.num[i] += (i < a.num.size() ? a.num[i] : 0) - (i < b.num.size() ? b.num[i] : 0);
    if (c.num[i] < 0) {
      c.num[i] += 10;
      --c.num[i + 1];
    }
  }
  while (c.num.size() > 1 && c.num.back() == 0)
    c.num.pop_back();
  return c;
}

big_number operator +(const big_number &a, const big_number &b) {
  if (a.sign && b.sign) {
    return add(a, b);
  } else if (a.sign && !b.sign) {
    big_number c = -b;
    if (a >= c)
      return sub(a, c);
    return -sub(c, a);
  } else if (!a.sign && b.sign) {
    big_number c = -a;
    if (b >= c)
      return sub(b, c);
    return -sub(c, b);
  } else {
    return -add(-a, -b);
  }
}

big_number operator -(const big_number &a, const big_number &b) {
  if (a.sign && b.sign) {
    if (a >= b)
      return sub(a, b);
    return -sub(b, a);
  } else if (a.sign && !b.sign) {
    return add(a, -b);
  } else if (!a.sign && b.sign) {
    return -add(-a, b);
  } else {
    big_number c = -a;
    big_number d = -b;
    if (d >= c)
      return sub(d, c);
    return -sub(c, d);
  }
}

int main() {
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#else
  ios::sync_with_stdio(false);
  cin.tie(0);
  cout.tie(0);
#endif

  string s;
  cin >> s;
  big_number a(s);
  cin >> s;
  big_number b(s);
  big_number c = a + b;
  if (!c.sign)
    cout << '-';
  for (int i = c.num.size() - 1; i >= 0; --i)
    cout << c.num[i];
  cout << '\n';
  return 0;
}

  return 0;
}
